@@ -7,6 +7,7 @@
 */
 
 #include "kded.h"
+#include "kded_debug.h"
 #include "kded_version.h"
 #include "kdedadaptor.h"
 
@@ -28,21 +29,11 @@
 #include <KDBusService>
 #include <KDirWatch>
 #include <KPluginFactory>
-#include <KPluginInfo>
 #include <KPluginMetaData>
-#include <KServiceTypeTrader>
 #include <KSharedConfig>
 
-#ifdef Q_OS_OSX
-#include <CoreFoundation/CoreFoundation.h>
-#endif
-
 #include <memory>
 
-Q_DECLARE_LOGGING_CATEGORY(KDED)
-
-Q_LOGGING_CATEGORY(KDED, "kf.kded", QtWarningMsg)
-
 Kded *Kded::_self = nullptr;
 
 static bool delayedCheck;
@@ -57,10 +48,9 @@ extern QDBUS_EXPORT void qDBusAddSpyHook(void (*)(const QDBusMessage &));
 
 static void runKonfUpdate()
 {
-    int ret = QProcess::execute(QStringLiteral(KCONF_UPDATE_EXE), QStringList());
-    if (ret != 0) {
-        qCWarning(KDED) << KCONF_UPDATE_EXE << "returned" << ret;
-    }
+    QProcess kconfUpdate;
+    kconfUpdate.start(QStringLiteral(KCONF_UPDATE_EXE), QStringList());
+    kconfUpdate.waitForFinished();
 }
 
 Kded::Kded()
@@ -75,15 +65,12 @@ Kded::Kded()
     m_serviceWatcher->setWatchMode(QDBusServiceWatcher::WatchForUnregistration);
     QObject::connect(m_serviceWatcher, &QDBusServiceWatcher::serviceUnregistered, this, &Kded::slotApplicationRemoved);
 
-    new KBuildsycocaAdaptor(this);
     new KdedAdaptor(this);
 
     QDBusConnection session = QDBusConnection::sessionBus();
     session.registerObject(QStringLiteral("/kbuildsycoca"), this);
     session.registerObject(QStringLiteral("/kded"), this);
 
-    qDBusAddSpyHook(messageFilter);
-
     m_pTimer->setSingleShot(true);
     connect(m_pTimer, &QTimer::timeout, this, static_cast<void (Kded::*)()>(&Kded::recreate));
 }
@@ -94,14 +81,9 @@ Kded::~Kded()
     m_pTimer->stop();
 
     for (auto it = m_modules.cbegin(); it != m_modules.cend(); ++it) {
-        KDEDModule *module(it.value());
-
-        // first disconnect otherwise slotKDEDModuleRemoved() is called
-        // and changes m_modules while we're iterating over it
-        disconnect(module, &KDEDModule::moduleDeleted, this, &Kded::slotKDEDModuleRemoved);
-
-        delete module;
+        delete *it;
     }
+    m_modules.clear();
 }
 
 // on-demand module loading
@@ -131,55 +113,22 @@ static int phaseForModule(const KPluginMetaData &module)
     return module.value(QStringLiteral("X-KDE-Kded-phase"), 2);
 }
 
-QVector<KPluginMetaData> Kded::availableModules() const
+QList<KPluginMetaData> Kded::availableModules() const
 {
-    QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kded"));
+    QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf6/kded"));
     QSet<QString> moduleIds;
     for (const KPluginMetaData &md : std::as_const(plugins)) {
         moduleIds.insert(md.pluginId());
     }
-#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
-    // also search for old .desktop based kded modules
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    const KPluginInfo::List oldStylePlugins = KPluginInfo::fromServices(KServiceTypeTrader::self()->query(QStringLiteral("KDEDModule")));
-    QT_WARNING_POP
-    for (const KPluginInfo &info : oldStylePlugins) {
-        if (moduleIds.contains(info.pluginName())) {
-            qCWarning(KDED).nospace() << "kded module " << info.pluginName()
-                                      << " has already been found using "
-                                         "JSON metadata, please don't install the now unneeded .desktop file ("
-                                      << info.entryPath() << ").";
-        } else {
-            qCDebug(KDED).nospace() << "kded module " << info.pluginName() << " still uses .desktop files (" << info.entryPath()
-                                    << "). Please port it to JSON metadata.";
-            plugins.append(info.toMetaData());
-        }
-    }
-#endif
     return plugins;
 }
 
 static KPluginMetaData findModule(const QString &id)
 {
-    KPluginMetaData module(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kded/") + id);
+    KPluginMetaData module(QStringLiteral("kf6/kded/") + id);
     if (module.isValid()) {
         return module;
     }
-#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
-    // TODO KF6: remove the .desktop fallback code
-    KService::Ptr oldStyleModule = KService::serviceByDesktopPath(QStringLiteral("kded/") + id + QStringLiteral(".desktop"));
-    if (oldStyleModule) {
-        qCDebug(KDED).nospace() << "kded module " << oldStyleModule->desktopEntryName() << " still uses .desktop files (" << oldStyleModule->entryPath()
-                                << "). Please port it to JSON metadata.";
-        QT_WARNING_PUSH
-        QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-        QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-        return KPluginInfo(oldStyleModule).toMetaData();
-        QT_WARNING_POP
-    }
-#endif
     qCWarning(KDED) << "could not find kded module with id" << id;
     return KPluginMetaData();
 }
@@ -187,32 +136,23 @@ static KPluginMetaData findModule(const QString &id)
 void Kded::initModules()
 {
     m_dontLoad.clear();
-#ifdef Q_OS_OSX
-    // it seems there is no reason to honour KDE_FULL_SESSION on OS X even if it's set for some reason.
-    // That way kdeinit5 is always auto-started if required (and the kded is as good a candidate
-    // for starting this service as any other application).
-    bool kde_running = false;
-#else
+
     bool kde_running = !qEnvironmentVariableIsEmpty("KDE_FULL_SESSION");
-#endif
     if (kde_running) {
-#ifndef Q_OS_WIN
         // not the same user like the one running the session (most likely we're run via sudo or something)
         const QByteArray sessionUID = qgetenv("KDE_SESSION_UID");
         if (!sessionUID.isEmpty() && uid_t(sessionUID.toInt()) != getuid()) {
             kde_running = false;
         }
-#endif
-        // TODO: Change 5 to KDED_VERSION_MAJOR the moment KF5 are stable
         // not the same kde version as the current desktop
         const QByteArray kdeSession = qgetenv("KDE_SESSION_VERSION");
-        if (kdeSession.toInt() != 5) {
+        if (kdeSession.toInt() != 6) {
             kde_running = false;
         }
     }
 
     // Preload kded modules.
-    const QVector<KPluginMetaData> kdedModules = availableModules();
+    const QList<KPluginMetaData> kdedModules = availableModules();
     for (const KPluginMetaData &module : kdedModules) {
         // Should the service load on startup?
         const bool autoload = isModuleAutoloaded(module);
@@ -259,11 +199,6 @@ void Kded::initModules()
     }
 }
 
-void Kded::loadSecondPhase()
-{
-    qCDebug(KDED) << "Second phase autoload is deprecated";
-}
-
 void Kded::noDemandLoad(const QString &obj)
 {
     m_dontLoad.insert(obj, this);
@@ -271,7 +206,7 @@ void Kded::noDemandLoad(const QString &obj)
 
 void Kded::setModuleAutoloading(const QString &obj, bool autoload)
 {
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kded5rc"));
     // Ensure the service exists.
     KPluginMetaData module = findModule(obj);
     if (!module.isValid()) {
@@ -292,7 +227,7 @@ bool Kded::isModuleAutoloaded(const KPluginMetaData &module) const
     if (!module.isValid()) {
         return false;
     }
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kded5rc"));
     bool autoload = module.value(QStringLiteral("X-KDE-Kded-autoload"), false);
     KConfigGroup cg(config, QStringLiteral("Module-").append(module.pluginId()));
     autoload = cg.readEntry("autoload", autoload);
@@ -316,7 +251,7 @@ bool Kded::isModuleLoadedOnDemand(const KPluginMetaData &module) const
     if (!module.isValid()) {
         return false;
     }
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kded5rc"));
     return module.value(QStringLiteral("X-KDE-Kded-load-on-demand"), true);
 }
 
@@ -360,22 +295,14 @@ KDEDModule *Kded::loadModule(const KPluginMetaData &module, bool onDemand)
     if (factoryResult) {
         kdedModule = factoryResult.plugin->create<KDEDModule>(this);
     } else {
-        // TODO: remove this fallback code, the kded modules should all be fixed instead
-        factoryResult = KPluginFactory::loadFactory(KPluginMetaData(QStringLiteral("kded_") + module.fileName()));
-        if (factoryResult) {
-            qCWarning(KDED).nospace() << "found kded module " << moduleId << " by prepending 'kded_' to the library path, please fix your metadata.";
-            kdedModule = factoryResult.plugin->create<KDEDModule>(this);
-        } else {
-            qCWarning(KDED).nospace() << "Could not load kded module " << moduleId << ":" << factoryResult.errorText
-                                      << " (library path was:" << module.fileName() << ")";
-        }
+        qCWarning(KDED).nospace() << "Could not load kded module " << moduleId << ":" << factoryResult.errorText << " (library path was:" << module.fileName()
+                                  << ")";
     }
 
     if (kdedModule) {
         kdedModule->setModuleName(moduleId);
         m_modules.insert(moduleId, kdedModule);
         // m_libs.insert(moduleId, lib);
-        connect(kdedModule, &KDEDModule::moduleDeleted, this, &Kded::slotKDEDModuleRemoved);
         qCDebug(KDED) << "Successfully loaded module" << moduleId;
         return kdedModule;
     }
@@ -399,11 +326,6 @@ QStringList Kded::loadedModules()
     return m_modules.keys();
 }
 
-void Kded::slotKDEDModuleRemoved(KDEDModule *module)
-{
-    m_modules.remove(module->moduleName());
-}
-
 void Kded::slotApplicationRemoved(const QString &name)
 {
 #if 0 // see kdedmodule.cpp (KDED_OBJECTS)
@@ -632,32 +554,9 @@ void KUpdateD::slotNewUpdateFile(const QString &dirty)
     m_pTimer->start(500);
 }
 
-KBuildsycocaAdaptor::KBuildsycocaAdaptor(QObject *parent)
-    : QDBusAbstractAdaptor(parent)
-{
-}
-
-void KBuildsycocaAdaptor::recreate()
-{
-    Kded::self()->recreate();
-}
-
-// KF6: remove
-bool KBuildsycocaAdaptor::isTestModeEnabled()
-{
-    return QStandardPaths::isTestModeEnabled();
-}
-
-// KF6: remove
-void KBuildsycocaAdaptor::setTestModeEnabled()
-{
-    QStandardPaths::setTestModeEnabled(true);
-}
-
 static void setupAppInfo(QApplication *app)
 {
-    app->setApplicationName(QStringLiteral("kded5"));
-    app->setApplicationDisplayName(QStringLiteral("KDE Daemon"));
+    app->setApplicationName(QStringLiteral("kded6"));
     app->setOrganizationDomain(QStringLiteral("kde.org"));
     app->setApplicationVersion(QStringLiteral(KDED_VERSION_STRING));
 }
@@ -692,20 +591,6 @@ static bool detectPlatform(int argc, char **argv)
 
 int main(int argc, char *argv[])
 {
-#ifdef Q_OS_OSX
-    CFBundleRef mainBundle = CFBundleGetMainBundle();
-    if (mainBundle) {
-        // get the application's Info Dictionary. For app bundles this would live in the bundle's Info.plist,
-        // for regular executables it is obtained in another way.
-        CFMutableDictionaryRef infoDict = (CFMutableDictionaryRef)CFBundleGetInfoDictionary(mainBundle);
-        if (infoDict) {
-            // Add or set the "LSUIElement" key with/to value "1". This can simply be a CFString.
-            CFDictionarySetValue(infoDict, CFSTR("LSUIElement"), CFSTR("1"));
-            // That's it. We're now considered as an "agent" by the window server, and thus will have
-            // neither menubar nor presence in the Dock or App Switcher.
-        }
-    }
-#endif
     // options.add("check", qi18n("Check Sycoca database only once"));
 
     // WABA: Make sure not to enable session management.
@@ -718,14 +603,13 @@ int main(int argc, char *argv[])
     // Since that option is no longer used at startup, we removed that speed
     // optimization for code clarity and easier support of standard parameters.
 
-    // Fixes blurry icons with Fractional scaling
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     if (unsetQpa) {
         qunsetenv("QT_QPA_PLATFORM");
     }
     setupAppInfo(&app);
     app.setQuitOnLastWindowClosed(false);
+    app.setQuitLockEnabled(false);
 
     QCommandLineParser parser;
     parser.addHelpOption();
@@ -743,33 +627,37 @@ int main(int argc, char *argv[])
         return 0;
     }
 
-    KDBusService service(KDBusService::Unique | KDBusService::StartupOption(parser.isSet(replaceOption) ? KDBusService::Replace : 0));
+    // Qt now has DBus in another thread, so we need to handle any messages
+    // between the service registration and our paths existing
+    // This means adding the spy now, so any received message gets
+    // posted to the main thread
+    qDBusAddSpyHook(Kded::messageFilter);
 
     QDBusConnectionInterface *bus = QDBusConnection::sessionBus().interface();
     // Also register as all the names we should respond to (org.kde.kcookiejar, org.kde.khotkeys etc.)
     // so that the calling code is independent from the physical "location" of the service.
-    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kded"));
+    const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf6/kded"));
     for (const KPluginMetaData &metaData : plugins) {
         const QString serviceName = metaData.value(QStringLiteral("X-KDE-DBus-ServiceName"));
         if (serviceName.isEmpty()) {
             continue;
         }
-        if (!bus->registerService(serviceName)) {
+        // register them queued as an old kded could be running at this point
+        if (!bus->registerService(serviceName, QDBusConnectionInterface::QueueService)) {
             qCWarning(KDED) << "Couldn't register name" << serviceName << "with DBUS - another process owns it already!";
         }
     }
+    KDBusService service(KDBusService::Unique | KDBusService::StartupOption(parser.isSet(replaceOption) ? KDBusService::Replace : 0));
 
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup cg(config, "General");
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kded5rc"));
+    KConfigGroup cg(config, QStringLiteral("General"));
 
     bCheckSycoca = cg.readEntry("CheckSycoca", true);
     bCheckUpdates = cg.readEntry("CheckUpdates", true);
     delayedCheck = cg.readEntry("DelayedCheck", false);
 
-#ifndef Q_OS_WIN
     signal(SIGTERM, sighandler);
     signal(SIGHUP, sighandler);
-#endif
 
     KCrash::setFlags(KCrash::AutoRestart);
 
